@@ -3,7 +3,7 @@
 /**
  * Common Option Constants For DBI Functions
  *
- * @version $Id: database_interface.lib.php 12393 2009-05-06 08:30:27Z helmo $
+ * @version $Id$
  * @package phpMyAdmin
  */
 if (! defined('PHPMYADMIN')) {
@@ -17,8 +17,8 @@ if (! defined('PHPMYADMIN')) {
 define('PMA_DBI_QUERY_STORE',       1);  // Force STORE_RESULT method, ignored by classic MySQL.
 define('PMA_DBI_QUERY_UNBUFFERED',  2);  // Do not read whole query
 // PMA_DBI_get_variable()
-define('PMA_DBI_GETVAR_SESSION', 1);
-define('PMA_DBI_GETVAR_GLOBAL', 2);
+define('PMA_DBI_GETVAR_SESSION',    1);
+define('PMA_DBI_GETVAR_GLOBAL',     2);
 
 /**
  * Checks one of the mysql extensions
@@ -33,7 +33,6 @@ function PMA_DBI_checkMysqlExtension($extension = 'mysql') {
     return true;
 }
 
-
 /**
  * check for requested extension
  */
@@ -264,19 +263,19 @@ function PMA_DBI_get_tables_full($database, $table = false, $tbl_is_group = fals
 
     if (! $GLOBALS['cfg']['Server']['DisableIS']) {
       // get table information from information_schema
-      if ($table) {
-          if (true === $tbl_is_group) {
-              $sql_where_table = 'AND `TABLE_NAME` LIKE \''
+        if ($table) {
+            if (true === $tbl_is_group) {
+                $sql_where_table = 'AND `TABLE_NAME` LIKE \''
                   . PMA_escape_mysql_wildcards(addslashes($table)) . '%\'';
-          } elseif ('comment' === $tbl_is_group) {
-              $sql_where_table = 'AND `TABLE_COMMENT` LIKE \''
+            } elseif ('comment' === $tbl_is_group) {
+                $sql_where_table = 'AND `TABLE_COMMENT` LIKE \''
                   . PMA_escape_mysql_wildcards(addslashes($table)) . '%\'';
-          } else {
-              $sql_where_table = 'AND `TABLE_NAME` = \'' . addslashes($table) . '\'';
-          }
-      } else {
-          $sql_where_table = '';
-      }
+            } else {
+                $sql_where_table = 'AND `TABLE_NAME` = \'' . addslashes($table) . '\'';
+            }
+        } else {
+            $sql_where_table = '';
+        }
 
       // for PMA bc:
       // `SCHEMA_FIELD_NAME` AS `SHOW_TABLE_STATUS_FIELD_NAME`
@@ -285,12 +284,13 @@ function PMA_DBI_get_tables_full($database, $table = false, $tbl_is_group = fals
       // added BINARY in the WHERE clause to force a case sensitive
       // comparison (if we are looking for the db Aa we don't want
       // to find the db aa)
-      $this_databases = array_map('PMA_sqlAddslashes', $databases);
+        $this_databases = array_map('PMA_sqlAddslashes', $databases);
 
-      $sql = '
+        $sql = '
            SELECT *,
                   `TABLE_SCHEMA`       AS `Db`,
                   `TABLE_NAME`         AS `Name`,
+                  `TABLE_TYPE`         ÀS `TABLE_TYPE`,
                   `ENGINE`             AS `Engine`,
                   `ENGINE`             AS `Type`,
                   `VERSION`            AS `Version`,
@@ -313,48 +313,35 @@ function PMA_DBI_get_tables_full($database, $table = false, $tbl_is_group = fals
             WHERE ' . (PMA_IS_WINDOWS ? '' : 'BINARY') . ' `TABLE_SCHEMA` IN (\'' . implode("', '", $this_databases) . '\')
               ' . $sql_where_table;
 
-      // Sort the tables
-      if ($sort_by == 'Name' && $GLOBALS['cfg']['NaturalOrder']) {
-          // This crazy bit of SQL was inspired by a post here:
-          // http://forums.mysql.com/read.php?10,34908,35959#msg-35959
+        // Sort the tables
+        $sql .= " ORDER BY $sort_by $sort_order";
 
-          // Find the longest table name
-          $max_name_sql = "SELECT MAX(LENGTH(TABLE_NAME)) FROM `information_schema`.`TABLES`
-                           WHERE `TABLE_SCHEMA` IN ('" . implode("', '", $this_databases) . "')"; 
-          $max_name_array = PMA_DBI_fetch_result($max_name_sql);
-          $max_name_length = $max_name_array[0];
+        if ($limit_count) {
+            $sql .= ' LIMIT ' . $limit_count . ' OFFSET ' . $limit_offset;
+        }
 
-          // Put the CASE statement SQL together.
-          $sql_case = '';
-          for ($i = 1; $i < $max_name_length; $i++) {
-              $sql_case .= " when substr(Name, $i) between '0' and '9' then $i";
-          }
-          $sql_case .= " ELSE $max_name_length end) ";
-
-          // Add the CASE statement to the main SQL
-          $sql .= " ORDER BY left(Name, (CASE ";
-          $sql .= $sql_case . "-1) $sort_order, 0+substr(Name, CASE";
-          $sql .= $sql_case . $sort_order;
-      } else {
-          // Just let MySQL sort as it normally does
-          $sql .= " ORDER BY $sort_by $sort_order";
-      }
-
-      if ($limit_count) {
-          $sql .= ' LIMIT ' . $limit_count . ' OFFSET ' . $limit_offset;
-      }
-
-      $tables = PMA_DBI_fetch_result($sql, array('TABLE_SCHEMA', 'TABLE_NAME'),
+        $tables = PMA_DBI_fetch_result($sql, array('TABLE_SCHEMA', 'TABLE_NAME'),
           null, $link);
-      unset($sql_where_table, $sql);
-    }
+        unset($sql_where_table, $sql);
+        if ($sort_by == 'Name' && $GLOBALS['cfg']['NaturalOrder']) {
+            // here, the array's first key is by schema name
+            foreach($tables as $one_database_name => $one_database_tables) {
+                uksort($one_database_tables, 'strnatcasecmp');
+
+                if ($sort_order == 'DESC') {
+                    $one_database_tables = array_reverse($one_database_tables);
+                }
+                $tables[$one_database_name] = $one_database_tables;
+            }
+        }
+    } // end (get information from table schema)
 
     // If permissions are wrong on even one database directory,
     // information_schema does not return any table info for any database
     // this is why we fall back to SHOW TABLE STATUS even for MySQL >= 50002
     if (empty($tables)) {
         foreach ($databases as $each_database) {
-            if (true === $tbl_is_group) {
+            if ($table || (true === $tbl_is_group)) {
                 $sql = 'SHOW TABLE STATUS FROM '
                     . PMA_backquote($each_database)
                     .' LIKE \'' . PMA_escape_mysql_wildcards(addslashes($table)) . '%\'';
@@ -460,7 +447,14 @@ function PMA_DBI_get_tables_full($database, $table = false, $tbl_is_group = fals
     // Note 2: Instead of array_merge(), simply use the + operator because
     //  array_merge() renumbers numeric keys starting with 0, therefore
     //  we would lose a db name thats consists only of numbers
-    PMA_Table::$cache = PMA_Table::$cache + $tables;
+    foreach($tables as $one_database => $its_tables) {
+        if (isset(PMA_Table::$cache[$one_database])) {
+            PMA_Table::$cache[$one_database] = PMA_Table::$cache[$one_database] + $tables[$one_database];
+        } else {
+            PMA_Table::$cache[$one_database] = $tables[$one_database];
+        }
+    }
+    unset($one_database, $its_tables);
 
     if (! is_array($database)) {
         if (isset($tables[$database])) {
@@ -591,7 +585,7 @@ function PMA_DBI_get_databases_full($database = null, $force_stats = false,
             $databases[$database_name]['SCHEMA_NAME']      = $database_name;
 
             if ($force_stats) {
-                require_once 'mysql_charsets.lib.php';
+                require_once './libraries/mysql_charsets.lib.php';
 
                 $databases[$database_name]['DEFAULT_COLLATION_NAME']
                     = PMA_getDbCollation($database_name);
@@ -616,8 +610,13 @@ function PMA_DBI_get_databases_full($database = null, $force_stats = false,
                         += $row['Max_data_length'];
                     $databases[$database_name]['SCHEMA_INDEX_LENGTH']
                         += $row['Index_length'];
-                    $databases[$database_name]['SCHEMA_DATA_FREE']
-                        += $row['Data_free'];
+
+                    // for InnoDB, this does not contain the number of 
+                    // overhead bytes but the total free space
+                    if ('InnoDB' != $row['Engine']) {
+                        $databases[$database_name]['SCHEMA_DATA_FREE']
+                            += $row['Data_free'];
+                    }
                     $databases[$database_name]['SCHEMA_LENGTH']
                         += $row['Data_length'] + $row['Index_length'];
                 }
@@ -821,6 +820,79 @@ function PMA_DBI_get_columns($database, $table, $full = false, $link = null)
 }
 
 /**
+ * array PMA_DBI_get_column_values (string $database, string $table, string $column , mysql db link $link = null)
+ *
+ * @param   string  $database   name of database
+ * @param   string  $table      name of table to retrieve columns from
+ * @param   string  $column     name of the column to retrieve data from 
+ * @param   mixed   $link       mysql link resource
+ * @return  array   $field_values
+ */
+
+function PMA_DBI_get_column_values($database, $table, $column, $link = null)
+{ 
+    $query = 'SELECT ';
+    for($i=0; $i< sizeof($column); $i++)
+    {
+        $query.= PMA_backquote($column[$i]);
+        if($i < (sizeof($column)-1))
+        {
+            $query.= ', ';   
+        }
+    }
+    $query.= ' FROM ' . PMA_backquote($database) . '.' . PMA_backquote($table);
+    $field_values = PMA_DBI_fetch_result($query, null, null, $link);
+    
+    if (! is_array($field_values) || count($field_values) < 1) {
+        return false;
+    }
+    return $field_values;
+}
+/**
+ * array PMA_DBI_get_table_data (string $database, string $table, mysql db link $link = null)
+ *
+ * @param   string  $database   name of database
+ * @param   string  $table      name of table to retrieve columns from
+ * @param   mixed   $link       mysql link resource
+ * @return  array   $result
+ */
+ 
+ function PMA_DBI_get_table_data($database, $table, $link = null)
+ { 
+                           
+    $result = PMA_DBI_fetch_result(
+        'SELECT * FROM ' . PMA_backquote($database) . '.' . PMA_backquote($table),
+        null,null, $link);
+                           
+    if (! is_array($result) || count($result) < 1) {
+        return false;
+    }                                                                                         
+    return $result;
+ }
+ 
+/**
+* array  PMA_DBI_get_table_indexes($database, $table, $link = null)
+* 
+* @param    string  $database   name of database
+* @param    string  $table      name of the table whose indexes are to be retreived
+* @param    mixed   $link       mysql link resource
+* @return   array   $indexes
+*/
+
+function PMA_DBI_get_table_indexes($database, $table, $link = null)
+{
+ 
+    $indexes = PMA_DBI_fetch_result(
+              'SHOW INDEXES FROM ' .PMA_backquote($database) . '.' . PMA_backquote($table),
+               null, null, $link);  
+    
+    if (! is_array($indexes) || count($indexes) < 1) {
+        return false;
+    }
+    return $indexes;
+}
+ 
+ /**
  * returns value of given mysql server variable
  *
  * @param   string  $var    mysql server variable name
@@ -828,6 +900,8 @@ function PMA_DBI_get_columns($database, $table, $full = false, $link = null)
  * @param   mixed   $link   mysql link resource|object
  * @return  mixed   value for mysql server variable
  */
+ 
+ 
 function PMA_DBI_get_variable($var, $type = PMA_DBI_GETVAR_SESSION, $link = null)
 {
     if ($link === null) {
@@ -853,6 +927,9 @@ function PMA_DBI_get_variable($var, $type = PMA_DBI_GETVAR_SESSION, $link = null
 }
 
 /**
+ *  Function called just after a connection to the MySQL database server has been established
+ *  It sets the connection collation, and determins the version of MySQL which is running.
+ *
  * @uses    ./libraries/charset_conversion.lib.php
  * @uses    PMA_DBI_QUERY_STORE
  * @uses    PMA_MYSQL_INT_VERSION to set it
@@ -1310,33 +1387,66 @@ function PMA_DBI_get_definition($db, $which, $name, $link = null)
  * @uses    PMA_DBI_fetch_result()
  * @param   string              $db     db name
  * @param   string              $table  table name
+ * @param   string              $delimiter  the delimiter to use (may be empty) 
  *
  * @return  array               information about triggers (may be empty)
  */
-function PMA_DBI_get_triggers($db, $table)
+function PMA_DBI_get_triggers($db, $table, $delimiter = '//')
 {
     $result = array();
 
+    if (! $GLOBALS['cfg']['Server']['DisableIS']) {
     // Note: in http://dev.mysql.com/doc/refman/5.0/en/faqs-triggers.html
     // their example uses WHERE TRIGGER_SCHEMA='dbname' so let's use this
     // instead of WHERE EVENT_OBJECT_SCHEMA='dbname'
-    $triggers = PMA_DBI_fetch_result("SELECT TRIGGER_SCHEMA, TRIGGER_NAME, EVENT_MANIPULATION, ACTION_TIMING, ACTION_STATEMENT, EVENT_OBJECT_SCHEMA, EVENT_OBJECT_TABLE FROM information_schema.TRIGGERS WHERE TRIGGER_SCHEMA= '" . PMA_sqlAddslashes($db,true) . "' and EVENT_OBJECT_TABLE = '" . PMA_sqlAddslashes($table, true) . "';");
+        $triggers = PMA_DBI_fetch_result("SELECT TRIGGER_SCHEMA, TRIGGER_NAME, EVENT_MANIPULATION, ACTION_TIMING, ACTION_STATEMENT, EVENT_OBJECT_SCHEMA, EVENT_OBJECT_TABLE FROM information_schema.TRIGGERS WHERE TRIGGER_SCHEMA= '" . PMA_sqlAddslashes($db,true) . "' and EVENT_OBJECT_TABLE = '" . PMA_sqlAddslashes($table, true) . "';");
+    } else {
+        $triggers = PMA_DBI_fetch_result("SHOW TRIGGERS FROM " . PMA_sqlAddslashes($db,true) . " LIKE '" . PMA_sqlAddslashes($table, true) . "';");
+    }
 
     if ($triggers) {
-        $delimiter = '//';
         foreach ($triggers as $trigger) {
+            if ($GLOBALS['cfg']['Server']['DisableIS']) {
+                $trigger['TRIGGER_NAME'] = $trigger['Trigger'];
+                $trigger['ACTION_TIMING'] = $trigger['Timing'];
+                $trigger['EVENT_MANIPULATION'] = $trigger['Event'];
+                $trigger['EVENT_OBJECT_TABLE'] = $trigger['Table'];
+                $trigger['ACTION_STATEMENT'] = $trigger['Statement'];
+            }
             $one_result = array();
             $one_result['name'] = $trigger['TRIGGER_NAME'];
             $one_result['action_timing'] = $trigger['ACTION_TIMING'];
             $one_result['event_manipulation'] = $trigger['EVENT_MANIPULATION'];
 
-            $one_result['full_trigger_name'] = PMA_backquote($trigger['TRIGGER_SCHEMA']) . '.' . PMA_backquote($trigger['TRIGGER_NAME']);
+            // do not prepend the schema name; this way, importing the
+            // definition into another schema will work
+            $one_result['full_trigger_name'] = PMA_backquote($trigger['TRIGGER_NAME']);
             $one_result['drop'] = 'DROP TRIGGER IF EXISTS ' . $one_result['full_trigger_name'];
-            $one_result['create'] = 'CREATE TRIGGER ' . $one_result['full_trigger_name'] . ' ' . $trigger['ACTION_TIMING']. ' ' . $trigger['EVENT_MANIPULATION'] . ' ON ' . PMA_backquote($trigger['EVENT_OBJECT_SCHEMA']) . '.' . PMA_backquote($trigger['EVENT_OBJECT_TABLE']) . "\n" . ' FOR EACH ROW ' . $trigger['ACTION_STATEMENT'] . "\n" . $delimiter . "\n";
+            $one_result['create'] = 'CREATE TRIGGER ' . $one_result['full_trigger_name'] . ' ' . $trigger['ACTION_TIMING']. ' ' . $trigger['EVENT_MANIPULATION'] . ' ON ' . PMA_backquote($trigger['EVENT_OBJECT_TABLE']) . "\n" . ' FOR EACH ROW ' . $trigger['ACTION_STATEMENT'] . "\n" . $delimiter . "\n";
 
             $result[] = $one_result;
         }
     }
     return($result);
 }
+
+/**
+ * Returns TRUE if $db.$view_name is a view, FALSE if not
+ *
+ * @uses   PMA_DBI_fetch_result()
+ * @param  string $db         database name
+ * @param  string $view_name  view/table name
+ *
+ * @return bool               TRUE if $db.$view_name is a view, FALSE if not
+ */
+function PMA_isView($db, $view_name)
+{
+    $result = PMA_DBI_fetch_result("SELECT TABLE_NAME FROM information_schema.VIEWS WHERE TABLE_SCHEMA = '".$db."' and TABLE_NAME = '".$view_name."';");
+    
+    if ($result) {
+        return TRUE;
+    } else {
+        return FALSE;
+    }
+}
 ?>
