@@ -9,7 +9,6 @@
  *
  * staybyte: speedup view on locked tables - 11 June 2001
  *
- * @uses    PMA_MYSQL_INT_VERSION
  * @uses    $cfg['ShowStats']
  * @uses    $cfg['ShowTooltip']
  * @uses    $cfg['ShowTooltipAliasTB']
@@ -32,7 +31,8 @@
  * @uses    strnatcasecmp()
  * @uses    count()
  * @uses    addslashes()
- * @version $Id: db_info.inc.php 11326 2008-06-17 21:32:48Z lem9 $
+ * @version $Id$
+ * @package phpMyAdmin
  */
 if (! defined('PHPMYADMIN')) {
     exit;
@@ -46,13 +46,14 @@ require_once './libraries/common.inc.php';
 /**
  * limits for table list
  */
-if (! isset($_SESSION['userconf']['table_limit_offset'])) {
-    $_SESSION['userconf']['table_limit_offset'] = 0;
+if (! isset($_SESSION['tmp_user_values']['table_limit_offset']) || $_SESSION['tmp_user_values']['table_limit_offset_db'] != $db) {
+    $_SESSION['tmp_user_values']['table_limit_offset'] = 0;
+    $_SESSION['tmp_user_values']['table_limit_offset_db'] = $db;
 }
 if (isset($_REQUEST['pos'])) {
-    $_SESSION['userconf']['table_limit_offset'] = (int) $_REQUEST['pos'];
+    $_SESSION['tmp_user_values']['table_limit_offset'] = (int) $_REQUEST['pos'];
 }
-$pos = $_SESSION['userconf']['table_limit_offset'];
+$pos = $_SESSION['tmp_user_values']['table_limit_offset'];
 
 /**
  * fills given tooltip arrays
@@ -111,7 +112,7 @@ $is_show_stats = $cfg['ShowStats'];
  */
 $db_is_information_schema = false;
 
-if (PMA_MYSQL_INT_VERSION >= 50002 && $db == 'information_schema') {
+if ($db == 'information_schema') {
     $is_show_stats = false;
     $db_is_information_schema = true;
 }
@@ -196,30 +197,54 @@ if (true === $cfg['SkipLockedTables']) {
 }
 
 if (! isset($sot_ready)) {
+
+    // Set some sorting defaults
+    $sort = 'Name';
+    $sort_order = 'ASC';
+
+    if (isset($_REQUEST['sort'])) {
+        $sortable_name_mappings = array(
+            'table'     => 'Name',
+            'records'   => 'Rows',
+            'type'      => 'Engine',
+            'collation' => 'Collation',
+            'size'      => 'Data_length',
+            'overhead'  => 'Data_free'
+        );
+
+        // Make sure the sort type is implemented
+        if ($sort = $sortable_name_mappings[$_REQUEST['sort']]) {
+            if ($_REQUEST['sort_order'] == 'DESC') {
+                $sort_order = 'DESC';
+            }
+        }
+    }
+
     if (! empty($tbl_group) && ! $cfg['ShowTooltipAliasTB']) {
         // only tables for selected group
-        $tables = PMA_DBI_get_tables_full($db, $tbl_group, true);
+        $tables = PMA_DBI_get_tables_full($db, $tbl_group, true, null, 0, false, $sort, $sort_order);
     } elseif (! empty($tbl_group) && $cfg['ShowTooltipAliasTB']) {
         // only tables for selected group,
         // but grouping is done on comment ...
-        $tables = PMA_DBI_get_tables_full($db, $tbl_group, 'comment');
+        $tables = PMA_DBI_get_tables_full($db, $tbl_group, 'comment', null, 0, false, $sort, $sort_order);
     } else {
         // all tables in db
         // - get the total number of tables
+        //  (needed for proper working of the MaxTableList feature)
         $tables = PMA_DBI_get_tables($db);
         $total_num_tables = count($tables);
         if (isset($sub_part) && $sub_part == '_export') {
             // (don't fetch only a subset if we are coming from db_export.php,
-            // because I think it's too risky to display only a subset of the 
+            // because I think it's too risky to display only a subset of the
             // table names when exporting a db)
             /**
              *
              * @todo Page selector for table names?
              */
-            $tables = PMA_DBI_get_tables_full($db, false, false, null, 0, false);
+            $tables = PMA_DBI_get_tables_full($db, false, false, null, 0, false, $sort, $sort_order);
         } else {
             // fetch the details for a possible limited subset
-            $tables = PMA_DBI_get_tables_full($db, false, false, null, $pos, true);
+            $tables = PMA_DBI_get_tables_full($db, false, false, null, $pos, true, $sort, $sort_order);
         }
     }
 
@@ -234,6 +259,7 @@ if (! isset($sot_ready)) {
  * @global int count of tables in db
  */
 $num_tables = count($tables);
+//  (needed for proper working of the MaxTableList feature)
 if (! isset($total_num_tables)) {
     $total_num_tables = $num_tables;
 }
