@@ -4,7 +4,8 @@
  * Ensure the database and the table exist (else move to the "parent" script)
  * and display headers
  *
- * @version $Id: db_table_exists.lib.php 12102 2008-12-09 14:03:57Z nijel $
+ * @version $Id$
+ * @package phpMyAdmin
  */
 if (! defined('PHPMYADMIN')) {
     exit;
@@ -13,6 +14,8 @@ if (! defined('PHPMYADMIN')) {
 /**
  *
  */
+require_once './libraries/Table.class.php';
+
 if (empty($is_db)) {
     if (strlen($db)) {
         $is_db = @PMA_DBI_select_db($db);
@@ -41,14 +44,19 @@ if (empty($is_db)) {
     }
 } // end if (ensures db exists)
 
-if (empty($is_table) && !defined('PMA_SUBMIT_MULT')) {
+if (empty($is_table) && !defined('PMA_SUBMIT_MULT') && ! defined('TABLE_MAY_BE_ABSENT')) {
     // Not a valid table name -> back to the db_sql.php
+
     if (strlen($table)) {
-        $_result = PMA_DBI_try_query(
-            'SHOW TABLES LIKE \'' . PMA_sqlAddslashes($table, true) . '\';',
-            null, PMA_DBI_QUERY_STORE);
-        $is_table = @PMA_DBI_num_rows($_result);
-        PMA_DBI_free_result($_result);
+        $is_table = isset(PMA_Table::$cache[$db][$table]);
+
+        if (! $is_table) {
+            $_result = PMA_DBI_try_query(
+                'SHOW TABLES LIKE \'' . PMA_sqlAddslashes($table, true) . '\';',
+                null, PMA_DBI_QUERY_STORE);
+            $is_table = @PMA_DBI_num_rows($_result);
+            PMA_DBI_free_result($_result);
+        }
     } else {
         $is_table = false;
     }
@@ -71,19 +79,8 @@ if (empty($is_table) && !defined('PMA_SUBMIT_MULT')) {
             }
 
             if (! $is_table) {
-                $url_params = array('reload' => 1, 'db' => $db);
-                if (isset($message)) {
-                    $url_params['message'] = $message;
-                }
-                if (! empty($sql_query)) {
-                    $url_params['sql_query'] = $sql_query;
-                }
-                if (isset($display_query)) {
-                    $url_params['display_query'] = $display_query;
-                }
-                PMA_sendHeaderLocation(
-                    $cfg['PmaAbsoluteUri'] . 'db_sql.php'
-                        . PMA_generate_common_url($url_params, '&'));
+                require 'db_sql.php';
+                exit;
             }
         }
 
