@@ -1,6 +1,12 @@
 <?php
-/* $Id: csv.php 9549 2006-10-13 08:14:31Z nijel $ */
-// vim: expandtab sw=4 ts=4 sts=4:
+/* vim: set expandtab sw=4 ts=4 sts=4: */
+/**
+ * @package phpMyAdmin-Export-CSV
+ * @version $Id$
+ */
+if (! defined('PHPMYADMIN')) {
+    exit;
+}
 
 /**
  * Set of functions used to build CSV dumps of tables
@@ -17,10 +23,11 @@ if (isset($plugin_list)) {
             array('type' => 'text', 'name' => 'escaped', 'text' => 'strFieldsEscapedBy'),
             array('type' => 'text', 'name' => 'terminated', 'text' => 'strLinesTerminatedBy'),
             array('type' => 'text', 'name' => 'null', 'text' => 'strReplaceNULLBy'),
+            array('type' => 'bool', 'name' => 'removeCRLF', 'text' => 'strRemoveCRLF'),
             array('type' => 'bool', 'name' => 'columns', 'text' => 'strPutColNames'),
             array('type' => 'hidden', 'name' => 'data'),
             ),
-        'options_text' => 'strCSVOptions',
+        'options_text' => 'strOptions',
         );
 } else {
 
@@ -63,7 +70,7 @@ function PMA_exportHeader() {
     // Here we just prepare some values for export
     if ($what == 'excel') {
         $csv_terminated      = "\015\012";
-        $csv_separator          = isset($GLOBALS['excel_edition']) && $GLOBALS['excel_edition'] == 'mac' ? ';' : ',';
+        $csv_separator          = isset($GLOBALS['excel_edition']) && $GLOBALS['excel_edition'] == 'mac_excel2003' ? ';' : ',';
         $csv_enclosed           = '"';
         $csv_escaped            = '"';
         if (isset($GLOBALS['excel_columns'])) {
@@ -173,14 +180,27 @@ function PMA_exportData($db, $table, $crlf, $error_url, $sql_query) {
             } elseif ($row[$j] == '0' || $row[$j] != '') {
                 // loic1 : always enclose fields
                 if ($what == 'excel') {
-                    $row[$j]       = ereg_replace("\015(\012)?", "\012", $row[$j]);
+                    $row[$j]       = preg_replace("/\015(\012)?/", "\012", $row[$j]);
+                }
+                // remove CRLF characters within field
+                if (isset($GLOBALS[$what . '_removeCRLF']) && $GLOBALS[$what . '_removeCRLF']) {
+                    $row[$j] = str_replace("\n", "", str_replace("\r", "", $row[$j]));
                 }
                 if ($csv_enclosed == '') {
                     $schema_insert .= $row[$j];
                 } else {
-                    $schema_insert .= $csv_enclosed
+                    // also double the escape string if found in the data
+                    if ('csv' == $what) {
+                        $schema_insert .= $csv_enclosed
+                                   . str_replace($csv_enclosed, $csv_escaped . $csv_enclosed, str_replace($csv_escaped, $csv_escaped . $csv_escaped, $row[$j]))
+                                   . $csv_enclosed;
+                    } else {
+                        // for excel, avoid a problem when a field contains
+                        // double quotes
+                        $schema_insert .= $csv_enclosed
                                    . str_replace($csv_enclosed, $csv_escaped . $csv_enclosed, $row[$j])
                                    . $csv_enclosed;
+                    }
                 }
             } else {
                 $schema_insert .= '';
