@@ -4,18 +4,17 @@
  * CSV import plugin for phpMyAdmin
  *
  * @todo    add an option for handling NULL values
- * @version $Id: csv.php 12600 2009-06-27 11:41:51Z lem9 $
+ * @version $Id$
  * @package phpMyAdmin-Import
  */
 if (! defined('PHPMYADMIN')) {
     exit;
 }
 
-/**
- *
- */
+$analyze = false;
+
 if ($plugin_param !== 'table') {
-    return;
+    $analyze = true;
 }
 
 if (isset($plugin_list)) {
@@ -29,10 +28,18 @@ if (isset($plugin_list)) {
             array('type' => 'text', 'name' => 'enclosed', 'text' => 'strFieldsEnclosedBy', 'size' => 2, 'len' => 2),
             array('type' => 'text', 'name' => 'escaped', 'text' => 'strFieldsEscapedBy', 'size' => 2, 'len' => 2),
             array('type' => 'text', 'name' => 'new_line', 'text' => 'strLinesTerminatedBy', 'size' => 2),
-            array('type' => 'text', 'name' => 'columns', 'text' => 'strColumnNames'),
             ),
         'options_text' => 'strOptions',
         );
+    
+    if ($plugin_param !== 'table') {
+        $plugin_list['csv']['options'][] =
+            array('type' => 'bool', 'name' => 'col_names', 'text' => 'strImportColNames');
+    } else {
+        $plugin_list['csv']['options'][] =
+            array('type' => 'text', 'name' => 'columns', 'text' => 'strColumnNames');
+    }
+    
     /* We do not define function when plugin is just queried for information above */
     return;
 }
@@ -74,53 +81,57 @@ if (strlen($csv_terminated) != 1) {
 }
 
 $buffer = '';
-if (isset($csv_replace)) {
-    $sql_template = 'REPLACE';
-} else {
-    $sql_template = 'INSERT';
-    if (isset($csv_ignore)) {
-        $sql_template .= ' IGNORE';
-    }
-}
-$sql_template .= ' INTO ' . PMA_backquote($table);
+$required_fields = 0;
 
-$tmp_fields = PMA_DBI_get_fields($db, $table);
-
-if (empty($csv_columns)) {
-    $fields = $tmp_fields;
-} else {
-    $sql_template .= ' (';
-    $fields = array();
-    $tmp   = split(',( ?)', $csv_columns);
-    foreach ($tmp as $key => $val) {
-        if (count($fields) > 0) {
-            $sql_template .= ', ';
+if (!$analyze) {
+    if (isset($csv_replace)) {
+        $sql_template = 'REPLACE';
+    } else {
+        $sql_template = 'INSERT';
+        if (isset($csv_ignore)) {
+            $sql_template .= ' IGNORE';
         }
-        /* Trim also `, if user already included backquoted fields */
-        $val = trim($val, " \t\r\n\0\x0B`");
-        $found = FALSE;
-        foreach ($tmp_fields as $id => $field) {
-            if ($field['Field'] == $val) {
-                $found = TRUE;
+    }
+    $sql_template .= ' INTO ' . PMA_backquote($table);
+
+    $tmp_fields = PMA_DBI_get_fields($db, $table);
+
+    if (empty($csv_columns)) {
+        $fields = $tmp_fields;
+    } else {
+        $sql_template .= ' (';
+        $fields = array();
+        $tmp   = split(',( ?)', $csv_columns);
+        foreach ($tmp as $key => $val) {
+            if (count($fields) > 0) {
+                $sql_template .= ', ';
+            }
+            /* Trim also `, if user already included backquoted fields */
+            $val = trim($val, " \t\r\n\0\x0B`");
+            $found = FALSE;
+            foreach ($tmp_fields as $id => $field) {
+                if ($field['Field'] == $val) {
+                    $found = TRUE;
+                    break;
+                }
+            }
+            if (!$found) {
+                $message = PMA_Message::error('strInvalidColumn');
+                $message->addParam($val);
+                $error = TRUE;
                 break;
             }
+            $fields[] = $field;
+            $sql_template .= PMA_backquote($val);
         }
-        if (!$found) {
-            $message = PMA_Message::error('strInvalidColumn');
-            $message->addParam($val);
-            $error = TRUE;
-            break;
-        }
-        $fields[] = $field;
-        $sql_template .= PMA_backquote($val);
+        $sql_template .= ') ';
     }
-    $sql_template .= ') ';
+    
+    $required_fields = count($fields);
+
+    $sql_template .= ' VALUES (';
 }
 
-$required_fields = count($fields);
-
-$sql_template .= ' VALUES (';
-
 // Defaults for parser
 $i = 0;
 $len = 0;
@@ -129,6 +140,14 @@ $lasti = -1;
 $values = array();
 $csv_finish = FALSE;
 
+$tempRow = array();
+$rows = array();
+$col_names = array();
+$tables = array();
+
+$col_count = 0;
+$max_cols = 0;
+
 while (!($finished && $i >= $len) && !$error && !$timeout_passed) {
     $data = PMA_importGetNextChunk();
     if ($data === FALSE) {
@@ -268,40 +287,57 @@ while (!($finished && $i >= $len) && !$error && !$timeout_passed) {
             if (!$csv_finish) {
                 $values[] = '';
             }
-            // Do we have correct count of values?
-            if (count($values) != $required_fields) {
-
-                // Hack for excel
-                if ($values[count($values) - 1] == ';') {
-                    unset($values[count($values) - 1]);
-                } else {
-                    $message = PMA_Message::error('strInvalidCSVFieldCount');
-                    $message->addParam($line);
-                    $error = TRUE;
-                    break;
+            
+            if ($analyze) {
+                foreach ($values as $ley => $val) {
+                    $tempRow[] = $val;
+                    ++$col_count;
                 }
+                
+                if ($col_count > $max_cols) {
+                    $max_cols = $col_count;
+                }
+                $col_count = 0;
+                
+                $rows[] = $tempRow;
+                $tempRow = array();
+            } else {
+                // Do we have correct count of values?
+                if (count($values) != $required_fields) {
+
+                    // Hack for excel
+                    if ($values[count($values) - 1] == ';') {
+                        unset($values[count($values) - 1]);
+                    } else {
+                        $message = PMA_Message::error('strInvalidCSVFieldCount');
+                        $message->addParam($line);
+                        $error = TRUE;
+                        break;
+                    }
+                }
+                
+                $first = TRUE;
+                $sql = $sql_template;
+                foreach ($values as $key => $val) {
+                    if (!$first) {
+                        $sql .= ', ';
+                    }
+                    if ($val === null) {
+                        $sql .= 'NULL';
+                    } else {
+                        $sql .= '\'' . addslashes($val) . '\'';
+                    }
+
+                    $first = FALSE;
+                }
+                $sql .= ')';
+                
+                /**
+                 * @todo maybe we could add original line to verbose SQL in comment
+                 */
+                PMA_importRunQuery($sql, $sql);
             }
-
-            $first = TRUE;
-            $sql = $sql_template;
-            foreach ($values as $key => $val) {
-                if (!$first) {
-                    $sql .= ', ';
-                }
-                if ($val === null) {
-                    $sql .= 'NULL';
-                } else {
-                    $sql .= '\'' . addslashes($val) . '\'';
-                }
-
-                $first = FALSE;
-            }
-            $sql .= ')';
-
-            /**
-             * @todo maybe we could add original line to verbose SQL in comment
-             */
-            PMA_importRunQuery($sql, $sql);
+            
             $line++;
             $csv_finish = FALSE;
             $values = array();
@@ -314,6 +350,73 @@ while (!($finished && $i >= $len) && !$error && !$timeout_passed) {
     } // End of parser loop
 } // End of import loop
 
+if ($analyze) {
+    /* Fill out all rows */
+    $num_rows = count($rows);
+    for ($i = 0; $i < $num_rows; ++$i) {
+        for ($j = count($rows[$i]); $j < $max_cols; ++$j) {
+            $rows[$i][] = 'NULL';
+        }
+    }
+    
+    if ($_REQUEST['csv_col_names']) {
+        $col_names = array_splice($rows, 0, 1);
+        $col_names = $col_names[0];
+    }
+    
+    if ((isset($col_names) && count($col_names) != $max_cols) || !isset($col_names)) {
+        // Fill out column names
+        for ($i = 0; $i < $max_cols; ++$i) {
+            $col_names[] = 'COL '.($i+1);
+        }
+    }
+    
+    if (strlen($db)) {
+        $result = PMA_DBI_fetch_result('SHOW TABLES');
+        $tbl_name = 'TABLE '.(count($result) + 1);
+    } else {
+        $tbl_name = 'TBL_NAME';
+    }
+    
+    $tables[] = array($tbl_name, $col_names, $rows);
+
+    /* Obtain the best-fit MySQL types for each column */
+    $analyses = array();
+    $analyses[] = PMA_analyzeTable($tables[0]);
+
+    /**
+     * string $db_name (no backquotes)
+     *
+     * array $table = array(table_name, array() column_names, array()() rows)
+     * array $tables = array of "$table"s
+     *
+     * array $analysis = array(array() column_types, array() column_sizes)
+     * array $analyses = array of "$analysis"s
+     *
+     * array $create = array of SQL strings
+     *
+     * array $options = an associative array of options
+     */
+
+    /* Set database name to the currently selected one, if applicable */
+    if (strlen($db)) {
+        $db_name = $db;
+        $options = array('create_db' => false);
+    } else {
+        $db_name = 'CSV_DB';
+        $options = NULL;
+    }
+
+    /* Non-applicable parameters */
+    $create = NULL;
+
+    /* Created and execute necessary SQL statements from data */
+    PMA_buildSQL($db_name, $tables, $analyses, $create, $options);
+
+    unset($tables);
+    unset($analyses);
+}
+
 // Commit any possible data in buffers
 PMA_importRunQuery();
 
