@@ -1,8 +1,13 @@
 <?php
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
+ * extracts table properties from create statement
  *
- * @version $Id: tbl_info.inc.php 11326 2008-06-17 21:32:48Z lem9 $
+ * @todo should be handled by class Table
+ * @todo this should be recoded as functions, to avoid messing with global variables
+ *
+ * @version $Id$
+ * @package phpMyAdmin
  */
 if (! defined('PHPMYADMIN')) {
     exit;
@@ -13,13 +18,6 @@ if (! defined('PHPMYADMIN')) {
  */
 require_once './libraries/Table.class.php';
 
-/**
- * extracts table properties from create statement
- *
- * @todo this should be recoded as functions,
- * to avoid messing with global variables
- */
-
 /**
  * requirements
  */
@@ -42,31 +40,35 @@ global $showtable, $tbl_is_view, $tbl_type, $show_comment, $tbl_collation,
 // otherwise error #1046, no database selected
 PMA_DBI_select_db($GLOBALS['db']);
 
-// The 'show table' statement works correct since 3.23.03
-$table_info_result   = PMA_DBI_query(
-    'SHOW TABLE STATUS LIKE \'' . PMA_sqlAddslashes($GLOBALS['table'], true) . '\';',
-    null, PMA_DBI_QUERY_STORE);
+
+/**
+ * Holds information about the current table
+ *
+ * @todo replace this by PMA_Table
+ * @global array $GLOBALS['showtable']
+ * @name $showtable
+ */
+$GLOBALS['showtable'] = array();
+
+// PMA_Table::sGetStatusInfo() does caching by default, but here
+// we force reading of the current table status
+// if $reread_info is true (for example, coming from tbl_operations.php
+// and we just changed the table's storage engine)
+$GLOBALS['showtable'] = PMA_Table::sGetStatusInfo($GLOBALS['db'], $GLOBALS['table'], null, (isset($reread_info) && $reread_info ? true : false));
 
 // need this test because when we are creating a table, we get 0 rows
 // from the SHOW TABLE query
 // and we don't want to mess up the $tbl_type coming from the form
 
-if ($table_info_result && PMA_DBI_num_rows($table_info_result) > 0) {
-    $showtable           = PMA_DBI_fetch_assoc($table_info_result);
-    PMA_DBI_free_result($table_info_result);
-    unset($table_info_result);
-
-    if (!isset($showtable['Type']) && isset($showtable['Engine'])) {
-        $showtable['Type'] =& $showtable['Engine'];
-    }
+if ($showtable) {
     if (PMA_Table::isView($GLOBALS['db'], $GLOBALS['table'])) {
         $tbl_is_view     = true;
         $tbl_type        = $GLOBALS['strView'];
         $show_comment    = null;
     } else {
         $tbl_is_view     = false;
-        $tbl_type        = isset($showtable['Type'])
-            ? strtoupper($showtable['Type'])
+        $tbl_type        = isset($showtable['Engine'])
+            ? strtoupper($showtable['Engine'])
             : '';
         // a new comment could be coming from tbl_operations.php
         // and we want to show it in the header
@@ -84,9 +86,10 @@ if ($table_info_result && PMA_DBI_num_rows($table_info_result) > 0) {
 
     if (null === $showtable['Rows']) {
         $showtable['Rows']   = PMA_Table::countRecords($GLOBALS['db'],
-            $showtable['Name'], true, true);
+            $showtable['Name'], true);
     }
     $table_info_num_rows = isset($showtable['Rows']) ? $showtable['Rows'] : 0;
+    $row_format = isset($showtable['Row_format']) ? $showtable['Row_format'] : '';
     $auto_increment      = isset($showtable['Auto_increment'])
         ? $showtable['Auto_increment']
         : '';
@@ -95,7 +98,7 @@ if ($table_info_result && PMA_DBI_num_rows($table_info_result) > 0) {
         ? explode(' ', $showtable['Create_options'])
         : array();
 
-    // export create options by its name as variables into gloabel namespace
+    // export create options by its name as variables into global namespace
     // f.e. pack_keys=1 becomes available as $pack_keys with value of '1'
     unset($pack_keys);
     foreach ($create_options as $each_create_option) {
