@@ -1,15 +1,20 @@
 <?php
-/* $Id: server_databases.php 9422 2006-09-20 11:15:56Z cybot_tm $ */
-// vim: expandtab sw=4 ts=4 sts=4:
+/* vim: set expandtab sw=4 ts=4 sts=4: */
+/**
+ *
+ * @version $Id$
+ * @package phpMyAdmin
+ */
 
 /**
  * Does the common work
  */
-require_once './libraries/common.lib.php';
+require_once './libraries/common.inc.php';
 
 
-$js_to_run = 'functions.js';
+$GLOBALS['js_include'][] = 'functions.js';
 require './libraries/server_common.inc.php';
+require './libraries/replication.inc.php';
 
 /**
  * avoids 'undefined index' errors
@@ -30,7 +35,7 @@ if (isset($_REQUEST['sort_order'])
 $dbstats    = empty($_REQUEST['dbstats']) ? 0 : 1;
 $pos        = empty($_REQUEST['pos']) ? 0 : (int) $_REQUEST['pos'];
 
-
+           
 /**
  * Drops multiple databases
  */
@@ -44,7 +49,7 @@ if (isset($_REQUEST['drop_selected_dbs_x'])) {
 if ((isset($_REQUEST['drop_selected_dbs']) || isset($_REQUEST['query_type']))
   && ($is_superuser || $cfg['AllowUserDropDatabase'])) {
     if (! isset($_REQUEST['selected_dbs']) && ! isset($_REQUEST['query_type'])) {
-        $message = $strNoDatabasesSelected;
+        $message = PMA_Message::error('strNoDatabasesSelected');
     } else {
         $action = 'server_databases.php';
         $submit_mult = 'drop_db' ;
@@ -53,12 +58,16 @@ if ((isset($_REQUEST['drop_selected_dbs']) || isset($_REQUEST['query_type']))
             $selected_db = $_REQUEST['selected_dbs'];
         }
         require './libraries/mult_submits.inc.php';
-        unset($action, $submit_mult, $err_url, $selected_db);
-        if ($mult_btn == $strYes) {
-            $message = sprintf($strDatabasesDropped, count($selected));
-        } else {
-            $message = sprintf($strDatabasesDropped, 0);
+        unset($action, $submit_mult, $err_url, $selected_db, $GLOBALS['db']);
+        if (empty($message)) {
+            $message = PMA_Message::success('strDatabasesDropped');
+            if ($mult_btn == $strYes) {
+                $message->addParam(count($selected));
+            } else {
+                $message->addParam(0);
+            }
         }
+
     }
 }
 
@@ -72,11 +81,11 @@ require './libraries/server_links.inc.php';
  * Displays the sub-page heading
  */
 echo '<h2>' . "\n"
-   . ( $GLOBALS['cfg']['MainPageIconic']
+   . ($GLOBALS['cfg']['MainPageIconic']
       ? '<img class="icon" src="' . $pmaThemeImage . 's_db.png" width="16"'
         .' height="16" alt="" />'
-      : '' )
-   . ( $dbstats ? $strDatabasesStats : $strDatabases ) . "\n"
+      : '')
+   . ($dbstats ? $strDatabasesStats : $strDatabases) . "\n"
    .'</h2>' . "\n";
 
 /**
@@ -85,7 +94,7 @@ echo '<h2>' . "\n"
 if ($server > 0) {
     $databases = PMA_DBI_get_databases_full(null, $dbstats, null, $sort_by,
         $sort_order, $pos, true);
-    $databases_count = $PMA_List_Database->count();
+    $databases_count = count($GLOBALS['pma']->databases);
 } else {
     $databases_count = 0;
 }
@@ -97,17 +106,13 @@ if ($server > 0) {
 if ($databases_count > 0) {
     reset($databases);
     $first_database = current($databases);
-
     // table col order
-    // there is no db specific collation or charset prior 4.1.0
-    if (PMA_MYSQL_INT_VERSION >= 40100) {
-        $column_order['DEFAULT_COLLATION_NAME'] = array(
-                'disp_name' => $strCollation,
-                'description_function' => 'PMA_getCollationDescr',
-                'format'    => 'string',
-                'footer'    => PMA_getServerCollation(),
-            );
-    }
+    $column_order['DEFAULT_COLLATION_NAME'] = array(
+            'disp_name' => $strCollation,
+            'description_function' => 'PMA_getCollationDescr',
+            'format'    => 'string',
+            'footer'    => PMA_getServerCollation(),
+        );
     $column_order['SCHEMA_TABLES'] = array(
         'disp_name' => $strNumTables,
         'format'    => 'number',
@@ -146,63 +151,7 @@ if ($databases_count > 0) {
         'sort_order' => $sort_order,
     );
 
-    if ($GLOBALS['cfg']['MaxDbList']
-     && $GLOBALS['cfg']['MaxDbList'] < $databases_count) {
-        // Move to the beginning or to the previous page
-        if ($pos > 0) {
-            // loic1: patch #474210 from Gosha Sakovich - part 1
-            if ($GLOBALS['cfg']['NavigationBarIconic']) {
-                $caption1 = '&lt;&lt;';
-                $caption2 = ' &lt; ';
-                $title1   = ' title="' . $GLOBALS['strPos1'] . '"';
-                $title2   = ' title="' . $GLOBALS['strPrevious'] . '"';
-            } else {
-                $caption1 = $GLOBALS['strPos1'] . ' &lt;&lt;';
-                $caption2 = $GLOBALS['strPrevious'] . ' &lt;';
-                $title1   = '';
-                $title2   = '';
-            } // end if... else...
-            $_url_params['pos'] = 0;
-            echo '<a' . $title1 . 'href="server_databases.php'
-                . PMA_generate_common_url($_url_params) . '">'
-                . $caption1 . '</a>';
-            $_url_params['pos'] = $pos - $GLOBALS['cfg']['MaxDbList'];
-            echo '<a' . $title2 . 'href="server_databases.php'
-                . PMA_generate_common_url($_url_params) . '">'
-                . $caption2 . '</a>';
-        }
-
-        echo '<form action="./server_databases.php" method="post">' . "\n";
-        echo PMA_generate_common_hidden_inputs($_url_params);
-        echo PMA_pageselector(
-                'server_databases.php' . PMA_generate_common_url($_url_params) . '&',
-                $GLOBALS['cfg']['MaxDbList'],
-                floor(($pos + 1) / $GLOBALS['cfg']['MaxDbList']) + 1,
-                ceil($databases_count / $GLOBALS['cfg']['MaxDbList']));
-        echo '</form>';
-
-        if ($pos + $GLOBALS['cfg']['MaxDbList'] < $databases_count) {
-            if ($GLOBALS['cfg']['NavigationBarIconic']) {
-                $caption3 = ' &gt; ';
-                $caption4 = '&gt;&gt;';
-                $title3   = ' title="' . $GLOBALS['strNext'] . '"';
-                $title4   = ' title="' . $GLOBALS['strEnd'] . '"';
-            } else {
-                $caption3 = '&gt; ' . $GLOBALS['strNext'];
-                $caption4 = '&gt;&gt; ' . $GLOBALS['strEnd'];
-                $title3   = '';
-                $title4   = '';
-            } // end if... else...
-            $_url_params['pos'] = $pos + $GLOBALS['cfg']['MaxDbList'];
-            echo '<a' . $title3 . 'href="server_databases.php'
-                . PMA_generate_common_url($_url_params) . '">'
-                . $caption3 . '</a>';
-            $_url_params['pos'] = floor($databases_count / $GLOBALS['cfg']['MaxDbList']) * $GLOBALS['cfg']['MaxDbList'];
-            echo '<a' . $title4 . 'href="server_databases.php'
-                . PMA_generate_common_url($_url_params) . '">'
-                . $caption4 . '</a>';
-        }
-    }
+    PMA_listNavigator($databases_count, $pos, $_url_params, 'server_databases.php', 'frame_content', $GLOBALS['cfg']['MaxDbList']);
 
     $_url_params['pos'] = $pos;
 
@@ -215,15 +164,15 @@ if ($databases_count > 0) {
     echo '<table id="tabledatabases" class="data">' . "\n"
        . '<thead>' . "\n"
        . '<tr>' . "\n"
-       . ($is_superuser || $cfg['AllowUserDropDatabase'] ? '        <th>&nbsp;</th>' . "\n" : '')
+       . ($is_superuser || $cfg['AllowUserDropDatabase'] ? '        <th></th>' . "\n" : '')
        . '    <th><a href="./server_databases.php' . PMA_generate_common_url($_url_params) . '">' . "\n"
        . '            ' . $strDatabase . "\n"
        . ($sort_by == 'SCHEMA_NAME' ? '                <img class="icon" src="' . $pmaThemeImage . 's_' . $sort_order . '.png" width="11" height="9"  alt="' . ($sort_order == 'asc' ? $strAscending : $strDescending) . '" />' . "\n" : '')
        . '        </a></th>' . "\n";
     $table_columns = 3;
-    foreach ( $column_order as $stat_name => $stat ) {
-        if ( array_key_exists( $stat_name, $first_database ) ) {
-            if ( $stat['format'] === 'byte' ) {
+    foreach ($column_order as $stat_name => $stat) {
+        if (array_key_exists($stat_name, $first_database)) {
+            if ($stat['format'] === 'byte') {
                 $table_columns += 2;
                 $colspan = ' colspan="2"';
             } else {
@@ -239,8 +188,19 @@ if ($databases_count > 0) {
                 .'        </a></th>' . "\n";
         }
     }
+    
+    foreach ($replication_types as $type) 
+    {
+      if ($type=="master")
+	$name = "strReplicationMaster";
+      elseif($type == "slave")
+	$name = "strReplicationSlave";
+      if (${"server_{$type}_status"})  
+        echo '    <th>'.$GLOBALS[$name].'</th>' . "\n";
+    }
+    
     if ($is_superuser) {
-        echo '    <th>' . ($cfg['PropertiesIconic'] ? '&nbsp;' : $strAction ) . "\n"
+        echo '    <th>' . ($cfg['PropertiesIconic'] ? '' : $strAction) . "\n"
            . '    </th>' . "\n";
     }
     echo '</tr>' . "\n"
@@ -249,12 +209,13 @@ if ($databases_count > 0) {
 
     $odd_row = true;
     foreach ($databases as $current) {
-        echo '<tr class="' . ( $odd_row ? 'odd' : 'even' ) . '">' . "\n";
+        echo '<tr class="' . ($odd_row ? 'odd' : 'even') . '">' . "\n";
         $odd_row = ! $odd_row;
 
-        if ( $is_superuser || $cfg['AllowUserDropDatabase'] ) {
+        if ($is_superuser || $cfg['AllowUserDropDatabase']) {
             echo '    <td class="tool">' . "\n";
-            if ($current['SCHEMA_NAME'] != 'mysql' && (PMA_MYSQL_INT_VERSION < 50002 || $current['SCHEMA_NAME'] != 'information_schema')) {
+            if ($current['SCHEMA_NAME'] != 'mysql'
+             && $current['SCHEMA_NAME'] != 'information_schema') {
                 echo '        <input type="checkbox" name="selected_dbs[]" title="' . htmlspecialchars($current['SCHEMA_NAME']) . '" value="' . htmlspecialchars($current['SCHEMA_NAME']) . '" ' . (empty($checkall) ? '' : 'checked="checked" ') . '/>' . "\n";
             } else {
                 echo '        <input type="checkbox" name="selected_dbs[]" title="' . htmlspecialchars($current['SCHEMA_NAME']) . '" value="' . htmlspecialchars($current['SCHEMA_NAME']) . '" disabled="disabled"/>' . "\n";
@@ -262,78 +223,118 @@ if ($databases_count > 0) {
             echo '    </td>' . "\n";
         }
         echo '    <td class="name">' . "\n"
-           . '        <a onclick="if ( window.parent.openDb(\'' . urlencode($current['SCHEMA_NAME']) . '\') ) return false;" href="index.php?' . $url_query . '&amp;db=' . urlencode($current['SCHEMA_NAME']) . '" title="' . sprintf($strJumpToDB, htmlspecialchars($current['SCHEMA_NAME'])) . '" target="_parent">' . "\n"
+           . '        <a onclick="'
+           . 'if (window.parent.openDb &amp;&amp; window.parent.openDb(\'' . PMA_jsFormat($current['SCHEMA_NAME'], false) . '\')) return false;'
+           . '" href="index.php?' . $url_query . '&amp;db='
+           . urlencode($current['SCHEMA_NAME']) . '" title="'
+           . sprintf($strJumpToDB, htmlspecialchars($current['SCHEMA_NAME']))
+           . '" target="_parent">' . "\n"
            . '            ' . htmlspecialchars($current['SCHEMA_NAME']) . "\n"
            . '        </a>' . "\n"
            . '    </td>' . "\n";
 
-        foreach ( $column_order as $stat_name => $stat ) {
-            if ( array_key_exists( $stat_name, $current ) ) {
-                if ( is_numeric( $stat['footer'] ) ) {
+        foreach ($column_order as $stat_name => $stat) {
+            if (array_key_exists($stat_name, $current)) {
+                if (is_numeric($stat['footer'])) {
                     $column_order[$stat_name]['footer'] += $current[$stat_name];
                 }
-                if ( $stat['format'] === 'byte' ) {
-                    list( $value, $unit ) = PMA_formatByteDown( $current[$stat_name], 3, 1 );
-                } elseif ( $stat['format'] === 'number' ) {
-                    $value = PMA_formatNumber( $current[$stat_name], 0 );
+                if ($stat['format'] === 'byte') {
+                    list($value, $unit) = PMA_formatByteDown($current[$stat_name], 3, 1);
+                } elseif ($stat['format'] === 'number') {
+                    $value = PMA_formatNumber($current[$stat_name], 0);
                 } else {
-                    $value = htmlentities( $current[$stat_name], 0 );
+                    $value = htmlentities($current[$stat_name], 0);
                 }
                 echo '    <td class="value">';
-                if ( isset( $stat['description_function'] ) ) {
-                    echo '<dfn title="' . $stat['description_function']( $current[$stat_name] ) . '">';
+                if (isset($stat['description_function'])) {
+                    echo '<dfn title="' . $stat['description_function']($current[$stat_name]) . '">';
                 }
                 echo $value;
-                if ( isset( $stat['description_function'] ) ) {
+                if (isset($stat['description_function'])) {
                     echo '</dfn>';
                 }
                 echo '</td>' . "\n";
-                if ( $stat['format'] === 'byte' ) {
+                if ($stat['format'] === 'byte') {
                     echo '    <td class="unit">' . $unit . '</td>' . "\n";
                 }
             }
         }
+        foreach ($replication_types as $type) {
+            if (${"server_{$type}_status"}) {
+                echo '<td class="tool" style="text-align: center;">' . "\n";
+
+                if (strlen(array_search($current["SCHEMA_NAME"], ${"server_{$type}_Ignore_DB"}))>0) {
+                    echo '<img class="icon" src="' . $pmaThemeImage . 's_cancel.png" width="16" height="16"  alt="NOT REPLICATED" />' . "\n";
+                } else {
+                    $key = array_search($current["SCHEMA_NAME"], ${"server_{$type}_Do_DB"});
+
+                    if (strlen($key) > 0 || (${"server_{$type}_Do_DB"}[0] == "" && count(${"server_{$type}_Do_DB"}) == 1)) {
+                        // if ($key != null) did not work for index "0"
+                        echo '<img class="icon" src="' . $pmaThemeImage . 's_success.png" width="16" height="16"  alt="REPLICATED" />' . "\n";
+                    } else {
+                        echo '';
+                    }
+                }
+
+                echo '</td>';
+            }
+        }
 
         if ($is_superuser) {
             echo '    <td class="tool">' . "\n"
-               . '        <a onclick="window.parent.setDb(\'' . urlencode($current['SCHEMA_NAME']) . '\');" href="./server_privileges.php?' . $url_query . '&amp;checkprivs=' . urlencode($current['SCHEMA_NAME']) . '" title="' . sprintf($strCheckPrivsLong, htmlspecialchars($current['SCHEMA_NAME'])) . '">'. "\n"
-               . '            ' .($cfg['PropertiesIconic'] ? '<img class="icon" src="' . $pmaThemeImage . 's_rights.png" width="16" height="16" alt=" ' .$strCheckPrivs . '" /> ' : $strCheckPrivs ). "\n"
+               . '        <a onclick="'
+               . 'if (window.parent.setDb) window.parent.setDb(\'' . PMA_jsFormat($current['SCHEMA_NAME']) . '\');'
+               . '" href="./server_privileges.php?' . $url_query
+               . '&amp;checkprivs=' . urlencode($current['SCHEMA_NAME'])
+               . '" title="' . sprintf($strCheckPrivsLong, htmlspecialchars($current['SCHEMA_NAME']))
+               . '">'. "\n"
+               . '            '
+               . ($cfg['PropertiesIconic']
+                 ? '<img class="icon" src="' . $pmaThemeImage . 's_rights.png" width="16" height="16" alt=" ' . $strCheckPrivs . '" /> '
+                 : $strCheckPrivs) . "\n"
                . '        </a></td>' . "\n";
         }
         echo '</tr>' . "\n";
-    } // end foreach ( $databases as $key => $current )
+    } // end foreach ($databases as $key => $current)
     unset($current, $odd_row);
 
     echo '<tr>' . "\n";
-    if ( $is_superuser || $cfg['AllowUserDropDatabase'] ) {
-        echo '    <th>&nbsp;</th>' . "\n";
+    if ($is_superuser || $cfg['AllowUserDropDatabase']) {
+        echo '    <th></th>' . "\n";
     }
     echo '    <th>' . $strTotalUC . ': ' . $databases_count . '</th>' . "\n";
-    foreach ( $column_order as $stat_name => $stat ) {
-        if ( array_key_exists( $stat_name, $first_database ) ) {
-            if ( $stat['format'] === 'byte' ) {
-                list( $value, $unit ) = PMA_formatByteDown( $stat['footer'], 3, 1 );
-            } elseif ( $stat['format'] === 'number' ) {
-                $value = PMA_formatNumber( $stat['footer'], 0 );
+    foreach ($column_order as $stat_name => $stat) {
+        if (array_key_exists($stat_name, $first_database)) {
+            if ($stat['format'] === 'byte') {
+                list($value, $unit) = PMA_formatByteDown($stat['footer'], 3, 1);
+            } elseif ($stat['format'] === 'number') {
+                $value = PMA_formatNumber($stat['footer'], 0);
             } else {
-                $value = htmlentities( $stat['footer'], 0 );
+                $value = htmlentities($stat['footer'], 0);
             }
             echo '    <th class="value">';
-            if ( isset( $stat['description_function'] ) ) {
-                echo '<dfn title="' . $stat['description_function']( $stat['footer'] ) . '">';
+            if (isset($stat['description_function'])) {
+                echo '<dfn title="' . $stat['description_function']($stat['footer']) . '">';
             }
             echo $value;
-            if ( isset( $stat['description_function'] ) ) {
+            if (isset($stat['description_function'])) {
                 echo '</dfn>';
             }
             echo '</th>' . "\n";
-            if ( $stat['format'] === 'byte' ) {
+            if ($stat['format'] === 'byte') {
                 echo '    <th class="unit">' . $unit . '</th>' . "\n";
             }
         }
     }
-    if ( $is_superuser ) {
-        echo '    <th>&nbsp;</th>' . "\n";
+    
+    foreach ($replication_types as $type) 
+    {
+      if (${"server_{$type}_status"})  
+        echo '    <th></th>' . "\n";
+    }
+
+    if ($is_superuser) {
+        echo '    <th></th>' . "\n";
     }
     echo '</tr>' . "\n";
     echo '</tbody>' . "\n"
@@ -343,16 +344,16 @@ if ($databases_count > 0) {
     if ($is_superuser || $cfg['AllowUserDropDatabase']) {
         $common_url_query = PMA_generate_common_url() . '&amp;sort_by=' . $sort_by . '&amp;sort_order=' . $sort_order . '&amp;dbstats=' . $dbstats;
         echo '<img class="selectallarrow" src="' . $pmaThemeImage . 'arrow_' . $text_dir . '.png" width="38" height="22" alt="' . $strWithChecked . '" />' . "\n"
-           . '<a href="./server_databases.php?' . $common_url_query . '&amp;checkall=1" onclick="if ( markAllRows(\'tabledatabases\') ) return false;">' . "\n"
+           . '<a href="./server_databases.php?' . $common_url_query . '&amp;checkall=1" onclick="if (markAllRows(\'tabledatabases\')) return false;">' . "\n"
            . '    ' . $strCheckAll . '</a> / ' . "\n"
-           . '<a href="./server_databases.php?' . $common_url_query . '" onclick="if ( unMarkAllRows(\'tabledatabases\') ) return false;">' . "\n"
+           . '<a href="./server_databases.php?' . $common_url_query . '" onclick="if (unMarkAllRows(\'tabledatabases\')) return false;">' . "\n"
            . '    ' . $strUncheckAll . '</a>' . "\n"
            . '<i>' . $strWithChecked . '</i>' . "\n";
-        PMA_buttonOrImage( 'drop_selected_dbs', 'mult_submit', 'drop_selected_dbs', $strDrop, 'b_deltbl.png' );
+        PMA_buttonOrImage('drop_selected_dbs', 'mult_submit', 'drop_selected_dbs', $strDrop, 'b_deltbl.png');
     }
 
     echo '<ul><li id="li_switch_dbstats"><strong>' . "\n";
-    if ( empty( $dbstats ) ) {
+    if (empty($dbstats)) {
         echo '        <a href="./server_databases.php?' . $url_query . '&amp;dbstats=1"'
             .' title="' . $strDatabasesStatsEnable . '">' . "\n"
             .'            ' . $strDatabasesStatsEnable;
@@ -361,9 +362,9 @@ if ($databases_count > 0) {
             .' title="' . $strDatabasesStatsDisable . '">' . "\n"
             .'            ' . $strDatabasesStatsDisable;
     }
-    echo '</a></strong><br />' . "\n"
-        .'        <div class="warning">'
-        . $strDatabasesStatsHeavyTraffic . '</div></li>' . "\n"
+    echo '</a></strong><br />' . "\n";
+    PMA_Message::warning('strDatabasesStatsHeavyTraffic')->display();
+    echo '</li>' . "\n"
         .'</ul>' . "\n";
     echo '</form>';
 } else {
@@ -374,10 +375,12 @@ unset($databases_count);
 /**
  * Create new database.
  */
-echo '<ul><li id="li_create_database">' . "\n";
-require './libraries/display_create_database.lib.php';
-echo '    </li>' . "\n";
-echo '</ul>' . "\n";
+if ($cfg['ShowCreateDb']) {
+    echo '<ul><li id="li_create_database">' . "\n";
+    require './libraries/display_create_database.lib.php';
+    echo '    </li>' . "\n";
+    echo '</ul>' . "\n";
+}
 
 /**
  * Sends the footer
