@@ -3,7 +3,7 @@
 /**
  * @todo    we must handle the case if sql.php is called directly with a query
  *          that returns 0 rows - to prevent cyclic redirects or includes
- * @version $Id: sql.php 12340 2009-04-09 14:20:44Z nijel $
+ * @version $Id$
  * @package phpMyAdmin
  */
 
@@ -96,8 +96,8 @@ PMA_displayTable_checkConfigParams();
  * Need to find the real end of rows?
  */
 if (isset($find_real_end) && $find_real_end) {
-    $unlim_num_rows = PMA_Table::countRecords($db, $table, true, true);
-    $_SESSION['userconf']['pos'] = @((ceil($unlim_num_rows / $_SESSION['userconf']['max_rows']) - 1) * $_SESSION['userconf']['max_rows']);
+    $unlim_num_rows = PMA_Table::countRecords($db, $table, $force_exact = true);
+    $_SESSION['tmp_user_values']['pos'] = @((ceil($unlim_num_rows / $_SESSION['tmp_user_values']['max_rows']) - 1) * $_SESSION['tmp_user_values']['max_rows']);
 }
 
 
@@ -252,13 +252,13 @@ if ($is_select) { // see line 141
 }
 
 // Do append a "LIMIT" clause?
-if ((! $cfg['ShowAll'] || $_SESSION['userconf']['max_rows'] != 'all')
+if ((! $cfg['ShowAll'] || $_SESSION['tmp_user_values']['max_rows'] != 'all')
  && ! ($is_count || $is_export || $is_func || $is_analyse)
  && isset($analyzed_sql[0]['queryflags']['select_from'])
  && ! isset($analyzed_sql[0]['queryflags']['offset'])
  && empty($analyzed_sql[0]['limit_clause'])
  ) {
-    $sql_limit_to_append = ' LIMIT ' . $_SESSION['userconf']['pos'] . ', ' . $_SESSION['userconf']['max_rows'] . " ";
+    $sql_limit_to_append = ' LIMIT ' . $_SESSION['tmp_user_values']['pos'] . ', ' . $_SESSION['tmp_user_values']['max_rows'] . " ";
 
     $full_sql_query  = $analyzed_sql[0]['section_before_limit'] . "\n" . $sql_limit_to_append . $analyzed_sql[0]['section_after_limit'];
     /**
@@ -311,7 +311,7 @@ if (isset($GLOBALS['show_as_php']) || !empty($GLOBALS['validatequery'])) {
                 $table = '';
             }
             $active_page = $goto;
-            $message = PMA_Message::rawError($error);
+            $message = htmlspecialchars(PMA_Message::rawError($error));
             /**
              * Go to target path.
              */
@@ -373,18 +373,17 @@ if (isset($GLOBALS['show_as_php']) || !empty($GLOBALS['validatequery'])) {
         $unlim_num_rows         = $num_rows;
         // if we did not append a limit, set this to get a correct
         // "Showing rows..." message
-        //$_SESSION['userconf']['max_rows'] = 'all';
+        //$_SESSION['tmp_user_values']['max_rows'] = 'all';
     } elseif ($is_select) {
 
         //    c o u n t    q u e r y
 
         // If we are "just browsing", there is only one table,
-        // and no where clause (or just 'WHERE 1 '),
-        // so we do a quick count (which uses MaxExactCount)
-        // because SQL_CALC_FOUND_ROWS
-        // is not quick on large InnoDB tables
+        // and no WHERE clause (or just 'WHERE 1 '),
+        // we do a quick count (which uses MaxExactCount) because 
+        // SQL_CALC_FOUND_ROWS is not quick on large InnoDB tables
 
-        // but do not count again if we did it previously
+        // However, do not count again if we did it previously
         // due to $find_real_end == true
 
         if (!$is_group
@@ -396,7 +395,7 @@ if (isset($GLOBALS['show_as_php']) || !empty($GLOBALS['validatequery'])) {
         ) {
 
             // "j u s t   b r o w s i n g"
-            $unlim_num_rows = PMA_Table::countRecords($db, $table, true);
+            $unlim_num_rows = PMA_Table::countRecords($db, $table);
 
         } else { // n o t   " j u s t   b r o w s i n g "
 
