@@ -2,7 +2,7 @@
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  *
- * @version $Id: tbl_operations.php 12297 2009-03-22 12:05:21Z lem9 $
+ * @version $Id$
  * @package phpMyAdmin
  */
 
@@ -95,6 +95,10 @@ if (isset($_REQUEST['submitoptions'])) {
         $tbl_type = $_REQUEST['new_tbl_type'];
         // reset the globals for the new engine
         PMA_set_global_variables_for_engine($tbl_type);
+        if ($is_maria) {
+            $transactional = (isset($transactional) && $transactional == '0') ? '0' : '1';
+            $page_checksum = (isset($page_checksum)) ? $page_checksum : '';
+        }
     }
 
     if (! empty($_REQUEST['tbl_collation'])
@@ -153,8 +157,16 @@ if (isset($_REQUEST['submitoptions'])) {
         $reread_info    = true;
         unset($table_alters);
         foreach (PMA_DBI_get_warnings() as $warning) {
-            $warning_messages[] = $warning['Level'] . ': #' . $warning['Code']
-                            . ' ' . $warning['Message'];
+            // In MariaDB 5.1.44, when altering a table from Maria to MyISAM 
+            // and if TRANSACTIONAL was set, the system reports an error;
+            // I discussed with a Maria developer and he agrees that this
+            // should not be reported with a Level of Error, so here
+            // I just ignore it. But there are other 1478 messages
+            // that it's better to show.
+            if (! ($_REQUEST['new_tbl_type'] == 'MyISAM' && $warning['Code'] == '1478' && $warning['Level'] == 'Error')) {
+                $warning_messages[] = $warning['Level'] . ': #' . $warning['Code']
+                    . ' ' . $warning['Message'];
+            }
         }
     }
 }
@@ -193,7 +205,7 @@ unset($reread_info);
  */
 require_once './libraries/tbl_links.inc.php';
 
-if (isset($result)) {
+if (isset($result) && empty($zero_rows)) {
     // set to success by default, because result set could be empty
     // (for example, a table rename)
     $_type = 'success';
@@ -428,12 +440,41 @@ if (isset($auto_increment) && strlen($auto_increment) > 0
     <?php
 } // end if (MYISAM|INNODB)
 
+// the outer array is for engines, the inner array contains the dropdown
+// option values as keys then the dropdown option labels
+
 $possible_row_formats = array(
-    'MARIA'  => array('FIXED','DYNAMIC','PAGE'),
-    'MYISAM' => array('FIXED','DYNAMIC'),
-    'PBXT'   => array('FIXED','DYNAMIC'),
-    'INNODB' => array('COMPACT','REDUNDANT')
+     'MARIA'  => array(
+        'FIXED'     => 'FIXED',
+        'DYNAMIC'   => 'DYNAMIC',
+        'PAGE'      => 'PAGE'
+            ),
+     'MYISAM' => array(
+         'FIXED'    => 'FIXED',
+         'DYNAMIC'  => 'DYNAMIC'
+     ),
+     'PBXT'   => array(
+         'FIXED'    => 'FIXED',
+         'DYNAMIC'  => 'DYNAMIC'
+     ),
+     'INNODB' => array(
+         'COMPACT'  => 'COMPACT',
+         'REDUNDANT' => 'REDUNDANT')
 );
+
+$innodb_engine_plugin = PMA_StorageEngine::getEngine('innodb');
+$innodb_plugin_version = $innodb_engine_plugin->getInnodbPluginVersion();
+if (!empty($innodb_plugin_version)) {
+    $innodb_file_format = $innodb_engine_plugin->getInnodbFileFormat();
+}  else {
+    $innodb_file_format = '';
+}
+if ('Barracuda' == $innodb_file_format && $innodb_engine_plugin->supportsFilePerTable()) {
+    $possible_row_formats['INNODB']['DYNAMIC'] = 'DYNAMIC';
+    $possible_row_formats['INNODB']['COMPRESSED'] = 'COMPRESSED';
+}
+unset($innodb_engine_plugin, $innodb_plugin_version, $innodb_file_format);
+
 // for MYISAM there is also COMPRESSED but it can be set only by the
 // myisampack utility, so don't offer here the choice because if we
 // try it inside an ALTER TABLE, MySQL (at least in 5.1.23-maria)
@@ -444,7 +485,7 @@ if (isset($possible_row_formats[$tbl_type])) {
     $current_row_format = strtoupper($showtable['Row_format']);
     echo '<tr><td><label for="new_row_format">ROW_FORMAT</label></td>';
     echo '<td>';
-    PMA_generate_html_dropdown('new_row_format', $possible_row_formats[$tbl_type], $current_row_format);
+    echo PMA_generate_html_dropdown('new_row_format', $possible_row_formats[$tbl_type], $current_row_format, 'new_row_format');
     unset($possible_row_formats, $current_row_format);
     echo '</td>';
     echo '</tr>';
@@ -485,7 +526,7 @@ if (isset($possible_row_formats[$tbl_type])) {
             'structure' => $strStrucOnly,
             'data'      => $strStrucData,
             'dataonly'  => $strDataOnly);
-        PMA_generate_html_radio('what', $choices, 'data', true);
+        PMA_display_html_radio('what', $choices, 'data', true);
         unset($choices);
 ?>
 
@@ -621,7 +662,7 @@ $this_url_params = array_merge($url_params,
             'OPTIMIZE' => $strOptimize,
             'REBUILD' => $strRebuild,
             'REPAIR' => $strRepair);
-        PMA_generate_html_radio('partition_operation', $choices, '', false);
+        PMA_display_html_radio('partition_operation', $choices, '', false);
         unset($choices);
         echo PMA_showMySQLDocu('partitioning_maintenance', 'partitioning_maintenance');
         // I'm not sure of the best way to display that; this link does
