@@ -1,11 +1,28 @@
 <?php
-    // unplanned execution path
-    if (!defined('PMA_MINIMUM_COMMON')) {
-        exit();
-    }
+/* vim: set expandtab sw=4 ts=4 sts=4: */
+/**
+ * main css file from theme Darkblue Orange
+ *
+ * @version $Id$
+ * @package phpMyAdmin-theme
+ * @subpackage Darkblue_orange
+ */
+
+// unplanned execution path
+if (!defined('PMA_MINIMUM_COMMON')) {
+    exit();
+}
 ?>
 /******************************************************************************/
 /* general tags */
+html {
+    font-size: <?php echo (null !== $_SESSION['PMA_Config']->get('fontsize') ? $_SESSION['PMA_Config']->get('fontsize') : $_COOKIE['pma_fontsize']); ?>;
+}
+
+input, select, textarea {
+    font-size: 1em;
+}
+
 body {
 <?php if (! empty($GLOBALS['cfg']['FontFamily'])) { ?>
     font-family:        <?php echo $GLOBALS['cfg']['FontFamily']; ?>;
@@ -13,7 +30,7 @@ body {
     padding:            0;
     margin:             0.5em;
     color:              <?php echo $GLOBALS['cfg']['MainColor']; ?>;
-    background:         <?php echo $GLOBALS['cfg']['MainBackground']; ?>;
+    background:         <?php echo (isset($_SESSION['tmp_user_values']['custom_color']) ? $_SESSION['tmp_user_values']['custom_color'] : $GLOBALS['cfg']['MainBackground']); ?>;
 }
 
 <?php if (! empty($GLOBALS['cfg']['FontFamilyFixed'])) { ?>
@@ -21,7 +38,6 @@ textarea, tt, pre, code {
     font-family:        <?php echo $GLOBALS['cfg']['FontFamilyFixed']; ?>;
 }
 <?php } ?>
-
 h1 {
     font-size:          180%;
     font-weight:        bold;
@@ -99,6 +115,7 @@ form {
 
 textarea {
     overflow:           visible;
+    height:             <?php echo ceil($GLOBALS['cfg']['TextareaRows'] * 1.2); ?>em;
 }
 
 fieldset {
@@ -112,9 +129,9 @@ fieldset fieldset {
 }
 
 fieldset legend {
-    color:              #666699;
-    font-weight:        bold;
     background:         <?php echo $GLOBALS['cfg']['MainBackground']; ?>;
+    font-weight:        bold;
+    color:              #444444;
     padding:            2px 2px 2px 2px;
 }
 
@@ -142,10 +159,17 @@ button {
 
 /******************************************************************************/
 /* classes */
+div.tools {
+    border: 1px solid #000000;
+    padding: 0.2em;
+}
 
+div.tools,
 fieldset.tblFooters {
     margin-top:         0;
     margin-bottom:      0.5em;
+    /* avoid a thick line since this should be used under another fieldset */
+    border-top:         0;
     text-align:         <?php echo $right; ?>;
     float:              none;
     clear:              both;
@@ -169,11 +193,13 @@ button.mult_submit {
 }
 
 /* odd items 1,3,5,7,... */
+table tr.odd th,
 .odd {
     background: <?php echo $GLOBALS['cfg']['BgOne']; ?>;
 }
 
 /* even items 2,4,6,8,... */
+table tr.even th,
 .even {
     background: <?php echo $GLOBALS['cfg']['BgTwo']; ?>;
 }
@@ -359,34 +385,65 @@ td .icon {
 }
 
 /* message boxes: warning, error, confirmation */
+.success h1,
+.notice h1,
+.warning h1,
+div.error h1 {
+    border-bottom:      2px solid;
+    font-weight:        bold;
+    text-align:         <?php echo $left; ?>;
+    margin:             0 0 0.2em 0;
+}
+
+div.success,
+div.notice,
+div.warning,
+div.error {
+    margin:             0.3em 0 0 0;
+    border:             2px solid;
+    width:              90%;
+    <?php if ($GLOBALS['cfg']['ErrorIconic']) { ?>
+    background-repeat:  no-repeat;
+        <?php if ($GLOBALS['text_dir'] === 'ltr') { ?>
+    background-position: 10px 50%;
+    padding:            0.1em 0.1em 0.1em 36px;
+        <?php } else { ?>
+    background-position: 99% 50%;
+    padding:            10px 5% 10px 10px;
+        <?php } ?>
+    <?php } else { ?>
+    padding:            0.3em;
+    <?php } ?>
+}
+
+.success {
+    color:              #000000;
+    background-color:   #f0fff0;
+}
+h1.success,
+div.success {
+    border-color:       #00FF00;
+    <?php if ($GLOBALS['cfg']['ErrorIconic']) { ?>
+    background-image:   url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_success.png);
+    <?php } ?>
+}
+.success h1 {
+    border-color:       #00FF00;
+}
+
 .notice {
     color:              #000000;
     background-color:   #FFFFDD;
 }
 h1.notice,
 div.notice {
-    margin:             0.5em 0 0.5em 0;
-    border:             0.1em solid #FFD700;
-    width:              90%;
-    <?php if ( $GLOBALS['cfg']['ErrorIconic'] ) { ?>
-    background-image:   url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_notice.png);
-    background-repeat:  no-repeat;
-        <?php if ( $GLOBALS['text_dir'] === 'ltr' ) { ?>
-    background-position: 10px 50%;
-    padding:            10px 10px 10px 36px;
-        <?php } else { ?>
-    background-position: 99% 50%;
-    padding:            10px 5% 10px 10px;
-        <?php } ?>
-    <?php } else { ?>
-    padding:            0.5em;
+    border-color:       #FFD700;
+    <?php if ($GLOBALS['cfg']['ErrorIconic']) { ?>
+    background-image:   url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_notice.png);
     <?php } ?>
 }
 .notice h1 {
-    border-bottom:      0.1em solid #FFD700;
-    font-weight:        bold;
-    text-align:         <?php echo $left; ?>;
-    margin:             0 0 0.2em 0;
+    border-color:       #FFD700;
 }
 
 .warning {
@@ -396,28 +453,13 @@ div.notice {
 p.warning,
 h1.warning,
 div.warning {
-    margin:             0.5em 0 0.5em 0;
-    border:             0.1em solid #CC0000;
-    width:              90%;
-    <?php if ( $GLOBALS['cfg']['ErrorIconic'] ) { ?>
-    background-image:   url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_warn.png);
-    background-repeat:  no-repeat;
-        <?php if ( $GLOBALS['text_dir'] === 'ltr' ) { ?>
-    background-position: 10px 50%;
-    padding:            10px 10px 10px 36px;
-        <?php } else { ?>
-    background-position: 99% 50%;
-    padding:            10px 5% 10px 10px;
-        <?php } ?>
-    <?php } else { ?>
-    padding:            0.5em;
+    border-color:       #CC0000;
+    <?php if ($GLOBALS['cfg']['ErrorIconic']) { ?>
+    background-image:   url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_warn.png);
     <?php } ?>
 }
 .warning h1 {
-    border-bottom:      0.1em solid #cc0000;
-    font-weight:        bold;
-    text-align:         <?php echo $left; ?>;
-    margin:             0 0 0.2em 0;
+    border-color:       #cc0000;
 }
 
 .error {
@@ -427,28 +469,13 @@ div.warning {
 
 h1.error,
 div.error {
-    margin:             0.5em 0 0.5em 0;
-    border:             0.1em solid #ff0000;
-    width:              90%;
-    <?php if ( $GLOBALS['cfg']['ErrorIconic'] ) { ?>
-    background-image:   url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_error.png);
-    background-repeat:  no-repeat;
-        <?php if ( $GLOBALS['text_dir'] === 'ltr' ) { ?>
-    background-position: 10px 50%;
-    padding:            10px 10px 10px 36px;
-        <?php } else { ?>
-    background-position: 99% 50%;
-    padding:            10px 5% 10px 10px;
-        <?php } ?>
-    <?php } else { ?>
-    padding:            0.5em;
+    border-color:       #ff0000;
+    <?php if ($GLOBALS['cfg']['ErrorIconic']) { ?>
+    background-image:   url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_error.png);
     <?php } ?>
 }
 div.error h1 {
-    border-bottom:      0.1em solid #ff0000;
-    font-weight:        bold;
-    text-align:         <?php echo $left; ?>;
-    margin:             0 0 0.2em 0;
+    border-color:       #ff0000;
 }
 
 .confirmation {
@@ -461,10 +488,10 @@ fieldset.confirmation legend {
     border-left:        0.1em solid #FF0000;
     border-right:       0.1em solid #FF0000;
     font-weight:        bold;
-    <?php if ( $GLOBALS['cfg']['ErrorIconic'] ) { ?>
-    background-image:   url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_really.png);
+    <?php if ($GLOBALS['cfg']['ErrorIconic']) { ?>
+    background-image:   url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_really.png);
     background-repeat:  no-repeat;
-        <?php if ( $GLOBALS['text_dir'] === 'ltr' ) { ?>
+        <?php if ($GLOBALS['text_dir'] === 'ltr') { ?>
     background-position: 5px 50%;
     padding:            0.2em 0.2em 0.2em 25px;
         <?php } else { ?>
@@ -487,16 +514,19 @@ fieldset.confirmation legend {
     background:         <?php echo $GLOBALS['cfg']['ThBackground']; ?>;
 }
 
+div.tools,
 .tblFooters {
     font-weight:        normal;
     color:              <?php echo $GLOBALS['cfg']['ThColor']; ?>;
     background:         <?php echo $GLOBALS['cfg']['ThBackground']; ?>;
-
 }
 
 .tblHeaders a:link,
 .tblHeaders a:active,
 .tblHeaders a:visited,
+div.tools a:link,
+div.tools a:visited,
+div.tools a:active,
 .tblFooters a:link,
 .tblFooters a:active,
 .tblFooters a:visited {
@@ -505,6 +535,7 @@ fieldset.confirmation legend {
 }
 
 .tblHeaders a:hover,
+div.tools a:hover,
 .tblFooters a:hover {
     text-decoration:    none;
     color:              #ffffff;
@@ -610,7 +641,7 @@ a.tabcaution:hover {
     background-color:   #FF0000;
 }
 
-<?php if ( $GLOBALS['cfg']['LightTabs'] ) { ?>
+<?php if ($GLOBALS['cfg']['LightTabs']) { ?>
 /* active tab */
 a.tabactive {
     color:              black;
@@ -646,14 +677,19 @@ a.tabcaution:hover,
 
 a.tab:hover,
 .tabactive {
-    background-color:   <?php echo $GLOBALS['cfg']['BgTwo']; ?>;
+    background-color:   <?php echo $GLOBALS['cfg']['MainBackground']; ?>;
+}
+
+/* to be able to cancel the bottom border, use <li class="active"> */
+ul#topmenu li.active {
+     border-bottom:      1pt solid <?php echo $GLOBALS['cfg']['MainBackground']; ?>;
 }
 
 /* disabled drop/empty tabs */
 span.tab,
 a.warning,
 span.tabcaution {
-    cursor:             url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>error.ico), default;
+    cursor:             url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>error.ico), default;
 }
 <?php } ?>
 /* end topmenu */
@@ -858,7 +894,8 @@ div#serverstatus table caption a.top {
 }
 
 div#serverstatus div#serverstatusqueriesdetails table,
-div#serverstatus table#serverstatustraffic,
+div#serverstatus table#serverstatustraffic_src,
+div#serverstatus table#serverstatustraffic_trg,
 div#serverstatus table#serverstatusconnections {
     float: <?php echo $left; ?>;
 }
@@ -947,10 +984,9 @@ div#queryboxcontainer div#bookmarkoptions {
 
 /* main page */
 #maincontainer {
-    background-image: url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>logo_right.png);
+    background-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>logo_right.png);
     background-position: <?php echo $right; ?> bottom;
     background-repeat: no-repeat;
-    border-bottom: 1px solid silver;
 }
 
 #mysqlmaininformation,
@@ -960,7 +996,7 @@ div#queryboxcontainer div#bookmarkoptions {
 }
 
 #maincontainer ul {
-    list-style-image: url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>item_<?php echo $GLOBALS['text_dir']; ?>.png);
+    list-style-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>item_<?php echo $GLOBALS['text_dir']; ?>.png);
     vertical-align: middle;
 }
 
@@ -973,96 +1009,98 @@ div#queryboxcontainer div#bookmarkoptions {
 <?php if ($GLOBALS['cfg']['MainPageIconic']) { ?>
 /* iconic view for ul items */
 li#li_create_database {
-    list-style-image: url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>b_newdb.png);
+    list-style-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>b_newdb.png);
 }
 
 li#li_select_lang {
-    list-style-image: url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_lang.png);
+    list-style-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_lang.png);
 }
 
 li#li_select_mysql_collation,
 li#li_select_mysql_charset {
-    list-style-image: url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_asci.png);
+    list-style-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_asci.png);
 }
 
 li#li_select_theme{
-    list-style-image: url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_theme.png);
+    list-style-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_theme.png);
 }
 
-li#li_server_info{
-    list-style-image: url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_host.png);
+li#li_server_info,
+li#li_server_version{
+    list-style-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_host.png);
 }
 
 li#li_user_info{
-    /* list-style-image: url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_rights.png); */
+    /* list-style-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_rights.png); */
 }
 
 li#li_mysql_status{
-    list-style-image: url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_status.png);
+    list-style-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_status.png);
 }
 
 li#li_mysql_variables{
-    list-style-image: url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_vars.png);
+    list-style-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_vars.png);
 }
 
 li#li_mysql_processes{
-    list-style-image: url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_process.png);
+    list-style-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_process.png);
 }
 
 li#li_mysql_collations{
-    list-style-image: url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_asci.png);
+    list-style-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_asci.png);
 }
 
 li#li_mysql_engines{
-    list-style-image: url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>b_engine.png);
+    list-style-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>b_engine.png);
 }
 
 li#li_mysql_binlogs {
-    list-style-image: url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_tbl.png);
+    list-style-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_tbl.png);
 }
 
 li#li_mysql_databases {
-    list-style-image: url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_db.png);
+    list-style-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_db.png);
 }
 
 li#li_export {
-    list-style-image: url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>b_export.png);
+    list-style-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>b_export.png);
 }
 
 li#li_import {
-    list-style-image: url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>b_import.png);
+    list-style-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>b_import.png);
 }
 
 li#li_change_password {
-    list-style-image: url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_passwd.png);
+    list-style-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_passwd.png);
 }
 
 li#li_log_out {
-    list-style-image: url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_loggoff.png);
+    list-style-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_loggoff.png);
 }
 
-li#li_pma_docs {
-    list-style-image: url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>b_docs.png);
+li#li_pma_docs,
+li#li_pma_wiki {
+    list-style-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>b_docs.png);
 }
 
 li#li_phpinfo {
-    list-style-image: url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>php_sym.png);
+    list-style-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>php_sym.png);
 }
 
 li#li_pma_homepage {
-    list-style-image: url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>b_home.png);
+    list-style-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>b_home.png);
 }
 
 li#li_mysql_privilegs{
-    list-style-image: url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_rights.png);
+    list-style-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_rights.png);
 }
 
 li#li_switch_dbstats {
-    list-style-image: url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>b_dbstatistics.png);
+    list-style-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>b_dbstatistics.png);
 }
 
 li#li_flush_privileges {
-    list-style-image: url(../<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_reload.png);
+    list-style-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath(); ?>s_reload.png);
 }
 /* END iconic view for ul items */
 <?php } /* end if $GLOBALS['cfg']['MainPageIconic'] */ ?>
@@ -1124,7 +1162,7 @@ li#li_flush_privileges {
     float: <?php echo $left; ?>;
 }
 
-#div_table_copy {
+#div_table_copy, #div_partition_maintenance, #div_referential_integrity, #div_table_maintenance {
     min-width: 48%;
     float: <?php echo $left; ?>;
 }
@@ -1147,3 +1185,69 @@ label.desc {
     width: 30em;
     float: <?php echo $left; ?>;
 }
+
+code.sql {
+    display:            block;
+    padding:            0.3em;
+    margin-top:         0;
+    margin-bottom:      0;
+    border:             <?php echo $GLOBALS['cfg']['MainColor']; ?> solid 1px;
+    border-top:         0;
+    border-bottom:      0;
+    max-height:         10em;
+    overflow:           auto;
+    background:         <?php echo $GLOBALS['cfg']['BgOne']; ?>;
+}
+
+#main_pane_left {
+    width:              60%;
+    float:              <?php echo $left; ?>;
+    padding-top:        1em;
+}
+
+#main_pane_right {
+    margin-<?php echo $left; ?>: 60%;
+    padding-top: 1em;
+    padding-<?php echo $left; ?>: 1em;
+}
+
+.group {
+    border-<?php echo $left; ?>: 0.3em solid <?php echo $GLOBALS['cfg']['ThBackground']; ?>;
+    margin-bottom:      1em;
+}
+
+.group h2 {
+    background-color:   <?php echo $GLOBALS['cfg']['ThBackground']; ?>;
+    padding:            0.1em 0.3em;
+    margin-top:         0;
+}
+
+#li_select_server {
+    padding-bottom:     0.3em;
+    border-bottom:      0.3em solid <?php echo $GLOBALS['cfg']['ThBackground']; ?>;
+    margin-bottom:      0.3em;
+}
+
+/**
+  *  Progress bar styles
+  */
+div.upload_progress_bar_outer
+{
+    border: 1px solid black; 
+    width: 202px;
+}
+
+div.upload_progress_bar_inner
+{
+    background-color: <?php echo (isset($_SESSION['userconf']['custom_color']) ? $_SESSION['userconf']['custom_color'] : $GLOBALS['cfg']['NaviBackground']); ?>; 
+    width: 0px; 
+    height: 12px; 
+    margin: 1px;
+}
+
+table#serverconnection_src_remote, 
+table#serverconnection_trg_remote,
+table#serverconnection_src_local, 
+table#serverconnection_trg_local  {
+  float:left;
+}
